[gnome-calendar] quick-add-popover: focus entry after calendar selection



commit 1e471b1b0c432c375dee1319534cb924c79aee37
Author: Mohammed Sadiq <sadiq sadiqpk org>
Date:   Thu Feb 9 07:59:54 2017 +0530

    quick-add-popover: focus entry after calendar selection
    
    Pressing 'Enter' key shall always save the event.
    So focusing on 'Add' button after selecting calendar is redundant.
    
    Instead, focus on the entry, so that the user can add more text without
    manually focusing.
    
    https://bugzilla.gnome.org/show_bug.cgi?id=778373

 src/gcal-quick-add-popover.c |    4 ++--
 1 files changed, 2 insertions(+), 2 deletions(-)
---
diff --git a/src/gcal-quick-add-popover.c b/src/gcal-quick-add-popover.c
index 88c780c..9170722 100644
--- a/src/gcal-quick-add-popover.c
+++ b/src/gcal-quick-add-popover.c
@@ -204,8 +204,8 @@ select_row (GcalQuickAddPopover *self,
   /* Return to the events page */
   gtk_stack_set_visible_child_name (GTK_STACK (self->stack), "events");
 
-  /* Focus back the "Create" button */
-  gtk_widget_grab_focus (self->add_button);
+  /* Focus back the event Entry */
+  gtk_entry_grab_focus_without_selecting (GTK_ENTRY (self->summary_entry));
 
   g_clear_object (&circle_pixbuf);
 }


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]